@@ -127,6 +127,7 @@ struct _grn_com {
   grn_com_queue new;
   grn_com_event *ev;
   void *opaque;
+  grn_bool accepting;
 };
 
 struct _grn_com_event {
@@ -160,6 +161,8 @@ grn_rc grn_com_init(void);
 void grn_com_fin(void);
 GRN_API grn_rc grn_com_event_init(grn_ctx *ctx, grn_com_event *ev, int max_nevents, int data_size);
 GRN_API grn_rc grn_com_event_fin(grn_ctx *ctx, grn_com_event *ev);
+grn_rc grn_com_event_start_accept(grn_ctx *ctx, grn_com_event *ev);
+grn_rc grn_com_event_stop_accept(grn_ctx *ctx, grn_com_event *ev);
 grn_rc grn_com_event_add(grn_ctx *ctx, grn_com_event *ev, grn_sock fd, int events, grn_com **com);
 grn_rc grn_com_event_mod(grn_ctx *ctx, grn_com_event *ev, grn_sock fd, int events, grn_com **com);
 GRN_API grn_rc grn_com_event_del(grn_ctx *ctx, grn_com_event *ev, grn_sock fd);
@@ -214,6 +217,7 @@ struct _grn_msg {
   grn_com_queue *old;
   grn_com_header header;
   grn_com_addr edge_id;
+  grn_com *acceptor;
 };
 
 GRN_API grn_rc grn_msg_send(grn_ctx *ctx, grn_obj *msg, int flags);
