@@ -400,6 +400,8 @@ grn_ctx_init(grn_ctx *ctx, int flags)
   grn_gctx.next->prev = ctx;
   grn_gctx.next = ctx;
   CRITICAL_SECTION_LEAVE(grn_glock);
+  ctx->trace[0] = NULL;
+  ctx->errbuf[0] = '\0';
   return ctx->rc;
 }
 
@@ -812,6 +814,8 @@ grn_rc
 grn_ctx_close(grn_ctx *ctx)
 {
   grn_rc rc = grn_ctx_fin(ctx);
+  ctx->next->prev = ctx->prev;
+  ctx->prev->next = ctx->next;
   GRN_GFREE(ctx);
   return rc;
 }
@@ -1140,6 +1144,26 @@ grn_ctx_sendv(grn_ctx *ctx, int argc, char **argv, int flags)
   return ctx->rc;
 }
 
+static int
+comment_command_p(const char *command, unsigned int length)
+{
+  const char *p, *e;
+
+  e = command + length;
+  for (p = command; p < e; p++) {
+    switch (*p) {
+    case '#' :
+      return GRN_TRUE;
+    case ' ' :
+    case '\t' :
+      break;
+    default :
+      return GRN_FALSE;
+    }
+  }
+  return GRN_FALSE;
+}
+
 unsigned int
 grn_ctx_send(grn_ctx *ctx, const char *str, unsigned int str_len, int flags)
 {
@@ -1165,7 +1189,8 @@ grn_ctx_send(grn_ctx *ctx, const char *str, unsigned int str_len, int flags)
       }
       goto exit;
     } else {
-      grn_obj *expr;
+      grn_obj *expr = NULL;
+      if (comment_command_p(str, str_len)) { goto output; };
       if (ctx->impl->qe_next) {
         grn_obj *val;
         expr = ctx->impl->qe_next;
@@ -1187,15 +1212,16 @@ grn_ctx_send(grn_ctx *ctx, const char *str, unsigned int str_len, int flags)
         }
       }
       if (ctx->stat == GRN_CTX_QUITTING) { ctx->stat = GRN_CTX_QUIT; }
+      if (!ctx->impl->qe_next) {
+        LAP("<", "rc=%d", ctx->rc);
+      }
+    output :
       if (!ERRP(ctx, GRN_CRIT)) {
         if (!(flags & GRN_CTX_QUIET) && ctx->impl->output) {
           ctx->impl->output(ctx, GRN_CTX_TAIL, ctx->impl->data.ptr);
         }
       }
       if (expr) { grn_expr_clear_vars(ctx, expr); }
-      if (!ctx->impl->qe_next) {
-        LAP("<", "rc=%d", ctx->rc);
-      }
       goto exit;
     }
   }
